<?php

namespace Drupal\opensearchtab\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;

/**
 * Configure Open Search Tab settings for this site.
 */
class OpenSearchSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'opensearchtab_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['opensearchtab.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $config = $this->config('opensearchtab.settings');

    $opensearchdescription_link = Link::fromTextAndUrl('Open Search Description', Url::fromRoute('opensearchtab.opensearchdescription'))->toString();

    $info_text = "See the XML of the open search tab:
      $opensearchdescription_link";

    $form['info_box'] = [
      '#type' => 'details',
      '#title' => $this->t('Infobox'),
      '#description' => $info_text,
      '#open' => TRUE,
    ];

    $form['opensearchtab_search_form_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search form path'),
      '#default_value' => $config->get('search-form-path'),
      '#description' => $this->t("Path to the search form, e.g.: '/search'. If empty, the following value will be used: '/search/node'."),
    ];

    $form['opensearchtab_search_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Search path'),
      '#default_value' => $config->get('search-path'),
      '#description' => $this->t("Path to the search, e.g.: '/search?{searchTerms}'. If empty, the following value will be used: '/search/node?keys={searchTerms}'."),
    ];

    $form['opensearchtab_suggestions_path_json'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Suggestions path (JSON)'),
      '#default_value' => $config->get('suggestions-path-json'),
      '#description' => $this->t("Path to the suggestions, e.g.: '/suggestions?{searchTerms}'."),
    ];

    $form['opensearchtab_suggestions_path_xml'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Suggestions path (XML)'),
      '#default_value' => $config->get('suggestions-path-xml'),
      '#description' => $this->t("Path to the suggestions, e.g.: '/suggestions?{searchTerms}'."),
    ];

    $form['opensearchtab_shortname'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Short name'),
      '#default_value' => $config->get('shortname'),
      '#description' => $this->t('Short name will be displayed in the search box. If empty, the site name be used.'),
    ];

    $form['opensearchtab_description'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Description'),
      '#default_value' => $config->get('description'),
    ];

    $form['opensearchtab_favicon_path'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Favicon path'),
      '#default_value' => $config->get('favicon-path'),
      '#description' => $this->t("Path to the Favicon, e.g.: '/themes/contrib/mytheme/favicon.ico'."),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!$form_state->isValueEmpty('opensearchtab_search_form_path')) {
      if (strlen($form_state->getValue('opensearchtab_search_form_path')) < 2) {
        $form_state->setErrorByName('opensearchtab_search_form_path', $this->t('Path is less than 2 characters'));
      }
    }

    if (!$form_state->isValueEmpty('opensearchtab_search_path')) {
      if (strlen($form_state->getValue('opensearchtab_search_path')) < 15) {
        $form_state->setErrorByName('opensearchtab_search_path', $this->t('Path is less than 15 characters'));
      }
    }

    if (!$form_state->isValueEmpty('opensearchtab_suggestions_path_json')) {
      if (strlen($form_state->getValue('opensearchtab_suggestions_path_json')) < 15) {
        $form_state->setErrorByName('opensearchtab_suggestions_path_json', $this->t('Path is less than 15 characters'));
      }
    }

    if (!$form_state->isValueEmpty('opensearchtab_suggestions_path_xml')) {
      if (strlen($form_state->getValue('opensearchtab_suggestions_path_xml')) < 15) {
        $form_state->setErrorByName('opensearchtab_suggestions_path_xml', $this->t('Path is less than 15 characters'));
      }
    }

    if (!$form_state->isValueEmpty('opensearchtab_shortname')) {
      if (strlen($form_state->getValue('opensearchtab_shortname')) < 3) {
        $form_state->setErrorByName('opensearchtab_shortname', $this->t('Short name is less than 3 characters'));
      }
    }

    if (!$form_state->isValueEmpty('opensearchtab_description')) {
      if (strlen($form_state->getValue('opensearchtab_description')) < 10) {
        $form_state->setErrorByName('opensearchtab_description', $this->t('Description is less than 10 characters'));
      }
    }

    if (!$form_state->isValueEmpty('opensearchtab_favicon_path')) {
      if (strlen($form_state->getValue('opensearchtab_favicon_path')) < 5) {
        $form_state->setErrorByName('opensearchtab_favicon_path', $this->t('Path is less than 5 characters'));
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);
    $this->config('opensearchtab.settings')
      ->set('search-form-path', $form_state->getValue('opensearchtab_search_form_path'))
      ->set('search-path', $form_state->getValue('opensearchtab_search_path'))
      ->set('suggestions-path-json', $form_state->getValue('opensearchtab_suggestions_path_json'))
      ->set('suggestions-path-xml', $form_state->getValue('opensearchtab_suggestions_path_xml'))
      ->set('shortname', $form_state->getValue('opensearchtab_shortname'))
      ->set('description', $form_state->getValue('opensearchtab_description'))
      ->set('favicon-path', $form_state->getValue('opensearchtab_favicon_path'))
      ->save();
  }

}
